@@ -86,12 +86,14 @@ class Drawing(xmlwriter.XMLwriter):
             'description': drawing_object[13],
             'shape': drawing_object[14],
             'url': None,
-            'tip': None
+            'tip': None,
+            'anchor': None
         }
 
         if len(drawing_object) > 15:
             obj['url'] = drawing_object[15]
             obj['tip'] = drawing_object[16]
+            obj['anchor'] = drawing_object[17]
 
         self.drawings.append(obj)
 
@@ -128,7 +130,12 @@ class Drawing(xmlwriter.XMLwriter):
 
         # Add attribute for images.
         if drawing['anchor_type'] == 2:
-            attributes.append(('editAs', 'oneCell'))
+            if drawing['anchor'] == 3:
+                attributes.append(('editAs', 'absolute'))
+            elif drawing['anchor'] == 1:
+                pass
+            else:
+                attributes.append(('editAs', 'oneCell'))
 
         # Add editAs attribute for shapes.
         if shape and shape.editAs:
@@ -720,7 +727,7 @@ class Drawing(xmlwriter.XMLwriter):
 
     def _write_a_solid_fill(self, rgb):
         # Write the <a:solidFill> element.
-        if not rgb is not None:
+        if rgb is not None:
             rgb = '000000'
 
         attributes = [('val', rgb)]
@@ -784,7 +791,7 @@ class Drawing(xmlwriter.XMLwriter):
         self._xml_start_tag('a:p')
 
         rotation = shape.format.rotation
-        if not rotation is not None:
+        if rotation is not None:
             rotation = 0
         rotation *= 60000
 
@@ -798,16 +805,16 @@ class Drawing(xmlwriter.XMLwriter):
         self._xml_start_tag('a:r')
 
         size = shape.format.size
-        if not size is not None:
+        if size is not None:
             size = 8
         size *= 100
 
         bold = shape.format.bold
-        if not bold is not None:
+        if bold is not None:
             bold = 0
 
         italic = shape.format.italic
-        if not italic is not None:
+        if italic is not None:
             italic = 0
 
         underline = shape['format']['underline']
